@@ -23,7 +23,7 @@
 #include <QRegExp>
 #include <QFileInfo>
 
-#include <KDebug>
+#include <QDebug>
 #include <KGlobal>
 #include <KLocalizedString>
 #include <KStandardDirs>
@@ -43,7 +43,6 @@ const QString MenuFile::MF_NEW =           "New";
 const QString MenuFile::MF_DIRECTORY =     "Directory";
 const QString MenuFile::MF_LAYOUT =        "Layout";
 const QString MenuFile::MF_MENUNAME =      "Menuname";
-const QString MenuFile::MF_SEPARATOR =     "Separator";
 const QString MenuFile::MF_MERGE =         "Merge";
 
 MenuFile::MenuFile(const QString &file)
@@ -65,7 +64,7 @@ bool MenuFile::load()
    if (!file.open( QIODevice::ReadOnly ))
    {
        if ( file.exists() )
-           kWarning() << "Could not read " << m_fileName ;
+           qWarning() << "Could not read " << m_fileName ;
        create();
        return false;
    }
@@ -74,7 +73,7 @@ bool MenuFile::load()
    int errorRow;
    int errorCol;
    if ( !m_doc.setContent( &file, &errorMsg, &errorRow, &errorCol ) ) {
-      kWarning() << "Parse error in " << m_fileName << ", line " << errorRow << ", col " << errorCol << ": " << errorMsg ;
+      qWarning() << "Parse error in " << m_fileName << ", line " << errorRow << ", col " << errorCol << ": " << errorMsg ;
       file.close();
       create();
       return false;
@@ -97,7 +96,7 @@ bool MenuFile::save()
 
    if (!file.open( QIODevice::WriteOnly ))
    {
-      kWarning() << "Could not write " << m_fileName ;
+      qWarning() << "Could not write " << m_fileName ;
       m_error = i18n("Could not write to %1", m_fileName);
       return false;
    }
@@ -110,7 +109,7 @@ bool MenuFile::save()
 
    if (file.error() != QFile::NoError)
    {
-      kWarning() << "Could not close " << m_fileName ;
+      qWarning() << "Could not close " << m_fileName ;
       m_error = i18n("Could not write to %1", m_fileName);
       return false;
    }
@@ -313,11 +312,7 @@ void MenuFile::setLayout(const QString &menuName, const QStringList &layout)
        it != layout.constEnd(); ++it)
    {
       QString li = *it;
-      if (li == ":S")
-      {
-         layoutNode.appendChild(m_doc.createElement(MF_SEPARATOR));
-      }
-      else if (li == ":M")
+      if (li == ":M")
       {
          QDomElement mergeNode = m_doc.createElement(MF_MERGE);
          mergeNode.setAttribute("type", "menus");
